<?php
$lang['expired_searchable'] = 'Utl&oslash;pte artikler f&aring;r vises i s&oslash;keresultat';
$lang['helpshowall'] = 'Vis alle artikler, uten &aring; ta hensyn til utl&oslash;psdato';
$lang['error_invaliddates'] = 'En eller flere av datoene som er oppgitt er ugyldige';
$lang['notify_n_draft_items_sub'] = '%d nyhetsartikler';
$lang['notify_n_draft_items'] = 'Du har %s som ikke er publiserte';
$lang['unlimited'] = 'Ubegrenset';
$lang['none'] = 'Ingen';
$lang['anonymous'] = 'Anonym';
$lang['unknown'] = 'Ukjent';
$lang['fesubmit_redirect'] = 'PageID eller alias som man omdirigeres til etter at en nyhetsartikkel har blitt opprettet via fesubmit handlingen';
$lang['allow_summary_wysiwyg'] = 'Tillat bruk av WYSIWYG redigerer i sammendragsfeltet';
$lang['title_browsecat_template'] = 'S&oslash;k-Kategorimal redigerer';
$lang['title_browsecat_sysdefault'] = 'Standard S&oslash;k-Kategorimal';
$lang['browsecattemplate'] = 'S&oslash;k-Kategorimaler';
$lang['error_filesize'] = 'En opplastet fil oversteg maksimalt tillatt st&oslash;rrelse';
$lang['post_date_desc'] = 'Publiseringsdato synkende';
$lang['post_date_asc'] = 'Publiseringsdato stigende';
$lang['expiry_date_desc'] = 'Utl&oslash;per dato synkende';
$lang['expiry_date_asc'] = 'Utl&oslash;per dato stigende';
$lang['title_desc'] = 'Tittel synkende';
$lang['title_asc'] = 'Tittel stigende';
$lang['fesubmit_status'] = 'Status for nyhetensartiklene som er innsendt via frontenden';
$lang['error_invalidfiletype'] = 'Kan ikke laste opp denne filtypen';
$lang['error_upload'] = 'Et problem oppstod under opplasting av fil';
$lang['error_movefile'] = 'Kunne ikke opprette fil: %s';
$lang['error_mkdir'] = 'Kunne ikke opprette katalog: %s';
$lang['expiry_interval'] = 'Antall dager (standard) f&oslash;r en artikkel skal utl&oslash;pe (om utl&oslash;per er valgt)';
$lang['removed'] = 'Fjernet';
$lang['msg_contenttype_removed'] = 'Nyhet innholdstypen har blitt fjernet. Vennligst plasser {news} tagger med passende parametere i din mal eller inne i sideinnholdet for &aring; gjenskape denne funksjonaliteten.';
$lang['delete_selected'] = 'Slett de valgte artiklene';
$lang['areyousure_deletemultiple'] = 'Er du sikker p&aring; du vil slette alle de valgte nyhetsartiklene?\nDette kan ikke angres!';
$lang['error_templatenamexists'] = 'En mal med det navnet eksisterer allerede';
$lang['error_noarticlesselected'] = 'Ingen artikler ble valgt';
$lang['reassign_category'] = 'Endre Kategori til';
$lang['select'] = 'Velg';
$lang['approve'] = 'Set status til &#039;Publisert&#039;';
$lang['revert'] = 'Sett status til &#039;kladd&#039;';
$lang['hide_summary_field'] = 'Skjul sammendragsfeltet under opprettelse eller redigering av artikler';
$lang['textbox'] = 'Tekst innskriving';
$lang['checkbox'] = 'Avkryssningsboks';
$lang['textarea'] = 'Tekstomr&aring;de';
$lang['file'] = 'Fil';
$lang['auto_create_thumbnails'] = 'Opprett automatisk miniatyrbilder for filer med disse filendelser';
$lang['allowed_upload_types'] = 'Tillat kun filer med disse filendelsene &aring; bli lastet opp';
$lang['fielddefupdated'] = 'Feltdefinisjon oppdatert';
$lang['editfielddef'] = 'Rediger feltdefinisjon';
$lang['up'] = 'Opp';
$lang['down'] = 'Ned';
$lang['fielddefdeleted'] = 'Feltdefinisjon slettet';
$lang['nameexists'] = 'Et felt med det navnet eksisterer allerede';
$lang['notanumber'] = 'Maksimum lengde er ikke et tall';
$lang['fielddef'] = 'Feltdefinisjon';
$lang['fielddefadded'] = 'Feltdefinisjon lagt til';
$lang['public'] = 'Offentlig';
$lang['type'] = 'Type ';
$lang['info_maxlength'] = 'Maksimum lengde p&aring;virker kun tekst innskrivingsfelter.';
$lang['maxlength'] = 'Maksimal lengde';
$lang['addfielddef'] = 'Legg til feltdefinisjon';
$lang['customfields'] = 'Felt definisjoner';
$lang['deprecated'] = 'ikke supportert';
$lang['subject_newnews'] = 'En nyhetsartikkel har blitt postet';
$lang['email_subject'] = 'Emne for den utg&aring;ende eposten';
$lang['email_template'] = 'Formatet p&aring; eposten';
$lang['formsubmit_emailaddress'] = 'Epostadresse &aring; motta meldinger om nyhetposteringer';
$lang['extra'] = 'Ekstra';
$lang['uploadscategory'] = 'Opplastings Kategori';
$lang['title_available_templates'] = 'Tilgjengelige maler';
$lang['resettodefault'] = 'Sett tilbake til Standard fabrikkinnstilling';
$lang['title_form_template'] = 'Skjema Mal Redigerer';
$lang['title_detail_template'] = 'Detaljmal redigerer';
$lang['title_summary_template'] = 'Sammendragmal redigerer';
$lang['prompt_templatename'] = 'Malnavn';
$lang['prompt_template'] = 'Mal kildekode';
$lang['title_form_sysdefault'] = 'Standard Skjemamal';
$lang['title_summary_sysdefault'] = 'Standard Sammendragsmal';
$lang['title_detail_sysdefault'] = 'Standard Detaljmal';
$lang['info_sysdefault2'] = '<strong>Merk:</strong> Denne fliken inneholder tekstomr&aring;der som tillater deg &aring; redigere de malene som vises n&aring;r du oppretter et &#039;nytt&#039; sammendrag, detalj, eller skjema mal. &Aring; endre innhold i denne fliken og klikke &#039;utf&oslash;r&#039; vil <strong>ikke ha effekt p&aring; n&aring;v&aelig;rende visninger</strong>.';
$lang['info_sysdefault'] = '<em>(malen som er benyttet som standard n&aring;r en ny mal velges)</em>';
$lang['template'] = 'Mal';
$lang['prompt_name'] = 'Navn';
$lang['prompt_default'] = 'Standard';
$lang['prompt_newtemplate'] = 'Opprett ny mal';
$lang['help_pagelimit'] = 'Maksimalt antall artikler &aring; vise (pr side). Om denne parameter ikke settes vil alle passende artikler vises. Om satt, og det er fler artikler tilgjengelig enn spesifisert i parameteren, vil tekst og lenker vises for &aring; tillate &aring; rulle gjennom resultatene';
$lang['prompt_page'] = 'Side';
$lang['firstpage'] = '<< ';
$lang['prevpage'] = '< ';
$lang['nextpage'] = ' >';
$lang['lastpage'] = ' >>';
$lang['prompt_of'] = 'av';
$lang['prompt_pagelimit'] = 'Sidegrense';
$lang['prompt_sorting'] = 'Sorter etter';
$lang['title_filter'] = 'Filtre';
$lang['published'] = 'Publisert';
$lang['draft'] = 'Kladd';
$lang['expired'] = 'Utl&oslash;pt';
$lang['author'] = 'Forfatter';
$lang['sysdefaults'] = 'Tilbakestill til standard';
$lang['restoretodefaultsmsg'] = 'Denne kommandoen vil tilbakestille malinnholdet til deres system standard. &Oslash;nsker du virkelig &aring; fortsette?';
$lang['addarticle'] = 'Legg til nyhetsartikkel';
$lang['articleadded'] = 'Artikkelen ble lagt til';
$lang['articleupdated'] = 'Artikkelen ble oppdatert.';
$lang['articledeleted'] = 'Artikkelen ble slettet.';
$lang['addcategory'] = 'Ny kategori';
$lang['categoryadded'] = 'Kategorien ble lagt til';
$lang['categoryupdated'] = 'Kategorien ble oppdatert.';
$lang['categorydeleted'] = 'Kategorien ble slettet.';
$lang['addnewsitem'] = 'Legg til nyhetsartikkel';
$lang['allcategories'] = 'Alle kategorier';
$lang['allentries'] = 'Alle oppf&oslash;ringer';
$lang['areyousure'] = '&Oslash;nsker du virkelig &aring; slette?';
$lang['articles'] = 'Nyhetsartikler';
$lang['cancel'] = 'Avbryt';
$lang['category'] = 'Kategori';
$lang['categories'] = 'Kategorier';
$lang['default_category'] = 'Standard Kategori';
$lang['content'] = 'Innhold';
$lang['dateformat'] = '%s er ikke et gyldig yyyy-mm-dd hh:mm:ss format';
$lang['delete'] = 'Slett';
$lang['description'] = 'Legg til, rediger og slett nyhetsartikler.';
$lang['formtemplate'] = 'Skjemamaler';
$lang['detailtemplate'] = 'Detaljmal';
$lang['default_templates'] = 'Standard maler';
$lang['detailtemplateupdated'] = 'Den oppdaterte Detaljmalen ble lagret til databasen.';
$lang['displaytemplate'] = 'Visningsmal';
$lang['edit'] = 'Rediger';
$lang['enddate'] = 'Sluttdato';
$lang['endrequiresstart'] = 'Om sluttdato er satt s&aring; kreves ogs&aring; en startdato.';
$lang['entries'] = '%s oppf&oslash;ringer';
$lang['status'] = 'Status ';
$lang['expiry'] = 'Utl&oslash;per';
$lang['filter'] = 'Filtrer';
$lang['more'] = 'Mer';
$lang['category_label'] = 'Kategori:';
$lang['author_label'] = 'Postet av:';
$lang['moretext'] = 'Mer Tekst';
$lang['name'] = 'Navn';
$lang['news'] = 'Nyheter';
$lang['news_return'] = 'Tilbake';
$lang['newcategory'] = 'Ny kategori';
$lang['needpermission'] = 'Du trenger &#039;%s&#039; rettighet for &aring; utf&oslash;re denne handlingen.';
$lang['nocategorygiven'] = 'Ingen kategori satt';
$lang['startdatetoolate'] = 'Startdato er for sen (etter sluttdato?)';
$lang['nocontentgiven'] = 'Innhold mangler';
$lang['noitemsfound'] = '<strong>Ingen</strong> artikler funnet i denne kategorien: %s';
$lang['nopostdategiven'] = 'Publiseringsdato mangler';
$lang['note'] = '<em>Merk:</em> Dato m&aring; v&aelig;re i et &#039;yyyy-mm-dd hh:mm:ss&#039; format.';
$lang['notitlegiven'] = 'Tittel mangler';
$lang['nonamegiven'] = 'Ingen navn oppgitt';
$lang['numbertodisplay'] = 'Antall som skal vises (ingen verdi - viser alle)';
$lang['print'] = 'Skriv ut';
$lang['postdate'] = 'Publiseringsdato';
$lang['postinstall'] = 'Husk &aring; tildele rettigheter for &quot;Modify News&quot; for brukere som skal administrere nyhetsartikler.';
$lang['selectcategory'] = 'Velg kategori';
$lang['showchildcategories'] = 'Vis underkategorier';
$lang['sortascending'] = 'Sorter stigende';
$lang['startdate'] = 'Startdato';
$lang['startoffset'] = 'Start visning p&aring; nde artikkel';
$lang['startrequiresend'] = 'Dersom du har en startdato m&aring; du ogs&aring; ha en sluttdato';
$lang['submit'] = 'Oppdater';
$lang['summary'] = 'Sammendrag';
$lang['summarytemplate'] = 'Sammendragsmal';
$lang['summarytemplateupdated'] = 'Nyhet sammendragsmalen ble oppdatert.';
$lang['title'] = 'Tittel';
$lang['options'] = 'Alternativer';
$lang['optionsupdated'] = 'Valgene ble oppdaterte';
$lang['useexpiration'] = 'Bruk utl&oslash;psdato';
$lang['eventdesc-NewsArticleAdded'] = 'Sendt n&aring;r en artikkel er lagt til.';
$lang['eventhelp-NewsArticleAdded'] = '<p>Sendt n&aring;r en artikkel er lagt til.</p>
<h4>Parametere</h4>
<ul>
<li>&quot;news_id&quot; - Id for nyhets artikkelen</li>
<li>&quot;category_id&quot; - Id for kategorien for denne artiklen</li>
<li>&quot;title&quot; - Artikkel tittel</li>
<li>&quot;content&quot; - Artikkelens innhold</li>
<li>&quot;summary&quot; - Artikkel sammendrag</li>
<li>&quot;status&quot; - Status for artikkelen (&quot;draft&quot; eller &quot;publish&quot;)</li>
<li>&quot;start_time&quot; - Dato for n&aring;r artikkelen skal begynne &aring; vises</li>
<li>&quot;end_time&quot; - Dato for n&aring;r artikkelen ikke skal vises lengre</li>
<li>&quot;useexp&quot; - Om utl&oslash;psdatoen skal ignoreres eller ikke</li>
</ul>';
$lang['eventdesc-NewsArticleEdited'] = 'Sendt n&aring;r en artikkel er redigert.';
$lang['eventhelp-NewsArticleEdited'] = '<p>Sendt n&aring;r en artikkel er redigert.</p>
<h4>Parametere</h4>
<ul>
<li>&quot;news_id&quot; - Id for nyhetsartikkelen</li>
<li>&quot;category_id&quot; - Id for kategorien for denne artikkelen</li>
<li>&quot;title&quot; - Artikkeltittel</li>
<li>&quot;content&quot; - Artikkel innhold</li>
<li>&quot;summary&quot; - Artikkel sammedrag</li>
<li>&quot;status&quot; - Artikkel status (&quot;draft&quot; eller &quot;publish&quot;)</li>
<li>&quot;start_time&quot; - Dato artikkelen skal begynne &aring; vises</li>
<li>&quot;end_time&quot; - Dato artikkelen ikke skal vises lengre</li>
<li>&quot;useexp&quot; - Om utl&oslash;psdatoen skal ignoreres eller ikke</li>
</ul>
';
$lang['eventdesc-NewsArticleDeleted'] = 'Sendt n&aring;r en artikkel er slettet.';
$lang['eventhelp-NewsArticleDeleted'] = '<p>Sendt n&aring;r en artikkel er slettet.</p>
<h4>Parametere</h4>
<ul>
<li>&quot;news_id&quot; - Id for nyhetsartikkelen</li>
</ul>
';
$lang['eventdesc-NewsCategoryAdded'] = 'Sendt n&aring;r en kategori er lagt til.';
$lang['eventhelp-NewsCategoryAdded'] = '<p>Sendt n&aring;r en kategori er lagt til.</p>
<h4>Parametere</h4>
<ul>
<li>&quot;category_id&quot; - Id for nyhetskategorien</li>
<li>&quot;name&quot; - Navn p&aring; nyhetskategorien</li>
</ul>
';
$lang['eventdesc-NewsCategoryEdited'] = 'Sendt n&aring;r en kategori er redigert.';
$lang['eventhelp-NewsCategoryEdited'] = '<p>Sendt n&aring;r en kategori er redigert.</p>
<h4>Parametere</h4>
<ul>
<li>&quot;category_id&quot; - Id for nyhetskategorien</li>
<li>&quot;name&quot; - Navn p&aring; nyhetskategorien</li>
<li>&quot;origname&quot; - Det orginale navnet p&aring; nyhetskategorien</li>
</ul>
';
$lang['eventdesc-NewsCategoryDeleted'] = 'Sendt n&aring;r en kategori er slettet.';
$lang['eventhelp-NewsCategoryDeleted'] = '<p>Sendt n&aring;r en kategori er slettet.</p>
<h4>Parametere</h4>
<ul>
<li>&quot;category_id&quot; - Id for den slettede nyhetskategorien</li>
<li>&quot;name&quot; - Navnet p&aring; den slettede kategorien</li>
</ul>
';
$lang['help_articleid'] = 'Denne parameter er kun gyldig i detaljvisning. Den tillater &aring; spesifisere hvilken nyhetsartikkel som skal vises i detaljmodus. Om den spesielle verdien -1 er benyttet vil systemet vise den nyeste, publiserte, ikke utl&oslash;pte artikkelen.';
$lang['helpnumber'] = 'Maksimalt antall elementer som skal vises (per side) (ingen verdi vil medf&oslash;re at alle elementer vises). Denne er synonym for pagelimit parameteren.';
$lang['helpstart'] = 'Start med artikkel n-- dersom ingen parameter er gitt vil visningen starte fra f&oslash;rste artikkel.';
$lang['helpcategory'] = 'Benyttet i sammendragsvisning for kun &aring; vise elementer fra den spesifiserte kategorien. <b>Bruk * etter navnet for &aring; vise underelementer.</b>  Flere kategorier kan bli brukt dersom disse er separert med komma. Om ingen verdi oppgis vil det resultere i at alle kategorier vises. Denne parameter virker ogs&aring; p&aring; frontend submit handlingen, men st&oslash;tter kun et kategori navn.';
$lang['helpmoretext'] = 'Tekst som skal vises p&aring; slutten av nyhetssaken dersom innlegget er lengre enn sammendragslengden. Standard verdi er &quot;more...&quot;';
$lang['helpsummarytemplate'] = 'Bruk en separat mal for &aring; vise artikkelsammendrag. Denne malen m&aring; eksistere og m&aring; v&aelig;re synlig i Sammendrag mal fliken i Nyheter administrasjonen, men den trenger ikke &aring; v&aelig;re standard. Om denne parameter ikke er satt, vil gjeldende standardmal benyttes.';
$lang['helpformtemplate'] = 'Bruk en database mal for &aring; vise artikkel innsending skjemaet. Denne malen m&aring; eksistere og m&aring; v&aelig;re synlig i Skjema mal fliken i Nyheter administrasjonen, men den trenger ikke &aring; v&aelig;re standard. Om denne parameter ikke er satt, vil gjeldende standardmal benyttes.';
$lang['helpbrowsecattemplate'] = 'Benytt en database-mal for &aring; vise kategoris&oslash;ket. Denne malen m&aring; eksistere og m&aring; v&aelig;re synlig i S&oslash;k-Kategori maler fliken i Nyhetsadministrasjonen, men den trenger ikke &aring; v&aelig;re satt som standard. Om denne parameter ikke er satt, vil gjeldende standardmal benyttes.';
$lang['helpdetailtemplate'] = 'Bruk en separat database mal for visning av artikkel detaljene. Denne malen m&aring; eksistere og m&aring; v&aelig;re synlig i Detalj mal fliken i Nyheter administrasjonen, men den trenger ikke &aring; v&aelig;re standard. Om denne parameter ikke er satt, vil gjeldende standardmal benyttes.';
$lang['helpsortby'] = 'Felt &aring; sortere etter.  Alternativene er &#039;news_date&#039;, &#039;summary&#039;, &#039;news_data&#039;, &#039;news_category&#039;, &#039;news_title&#039;, &#039;news_extra&#039;, &#039;end_time&#039;, &#039;start_time&#039;, &#039;random&#039;.  Standardsetting er &#039;news_date&#039;. Om tilfeldig(random) er valgt vil sortasc parameteren bli ignorert.';
$lang['helpsortasc'] = 'Sorter nyhetselementer i stigende rekkef&oslash;lge i stedet for synkende.';
$lang['helpdetailpage'] = 'Side hvor nyhetsdetaljer skal vises. Dette kan enten v&aelig;re et sidealias eller en id. Benyttes for &aring; tillate visning av detaljer i en annen mal enn sammendragsmalen.';
$lang['helpshowarchive'] = 'Vis bare utdaterte nyhetsartikler.';
$lang['helpbrowsecat'] = 'Viser en s&oslash;kbar kategoriliste';
$lang['helpaction'] = 'Overstyrer standard handlingen. Mulige verdier er:
<ul>
<li>&quot;detail&quot; - for &aring; vise en spesifisert articleid i detaljvisningsmodus.</li>
<li>&quot;default&quot; - for &aring; vise sammendragsvisningen</li>
<li>&quot;fesubmit&quot; - for &aring; vise et forside skjema for &aring; tillate brukere &aring; bidra med nyhetsartikler fra nettsiden.</li>
<li>&quot;browsecat&quot; - for &aring; vise en s&oslash;kbar kategoriliste.</li>
</ul>';
$lang['help'] = '<h3>Viktige merknader</h3>
<p>Versjon 2.9 av News og h&oslash;yere har fjernet formatpostdate medlemmet fra malene og har ogs&aring; fjernet dateformat parameteren. Du b&oslash;r benytte  cms_date_format  (slik det er vist i standard malene) for &aring; formatere datoer. Og du b&oslash;r benytte entry->postdate i stedet for entry->formatpostdate i dine maler. <br />Tips: For &aring; f&aring; norsk &aelig; og &oslash; p&aring; ukedag s&aring; kan det hende du ogs&aring; m&aring; tilf&oslash;ye  |htmlentities  bak  cms_date_format  som dette: {$entry->postdate|cms_date_format:&quot;%A %e. %B %Y&quot;|htmlentities}</p>

<h3>Hva gj&oslash;r denne modulen?</h3>
<p>News er en modul for visning av nyhetsartikler p&aring; din side. Den ligner en blogg, men har flere muligheter!.  
N&aring;r modulen er installert, blir det lagt til en administrasjonsside for Nyheter i administrasjonsmenyen, som vil tillate deg &aring; velg og  legge til nyhetskategori.  
	N&aring;r en nyhetskategori er opprettet eller valgt, vil det vises en liste med nyhetsartikler for den kategorien.  
Herfra kan du legge til, redigere eller slette nyheter for kategorien.</p>
        <h4>Mange visnings m&aring;ter</h4>
	<p>Parameterne som er st&oslash;ttet av nyhets modulen, og st&oslash;tte for mange maler p&aring; en gang vil si at dine muligheter for &aring; vise nyhetsartikler er ubegrenset.</p>
        <h4>Egendefinerte felter</h4>
	<p>Nyhetsmodulen tillater definering av mange egendefinerte felter (inkludert filer og bilder) som vil tillate deg &aring; koble pdf filer eller flere bilders til dine artikler.</p>
        <h4>Kategorier</h4>
	<p>Nyheter st&oslash;tter en hierarktisk kategori mekanisme for &aring; organisere dine artikler. En hyhetsartikkel kan kun tilh&oslash;re en posisjon i hierarkiet.</p>
	<h4>Utl&oslash;psdato og Status</h4>
	<p>Hver nyhetsartikkel kan ha en utl&oslash;psdato(valgfritt) og n&aring;r denne utl&oslash;per vil artikkelen ikke vises p&aring; din nettside. I tillegg kan artikler ogs&aring; merkes som <em>kladd</em> for &aring; sette dem til &aring; ikke vises p&aring; din nettside.</p>
	<h3>Sikkerhet</h3>
	<p>Brukeren m&aring; tilh&oslash;re en gruppe med &#039;Modify News&#039; tillatelse for &aring; kunne legge til, redigere elle slette Nyhetsartikler.</p>
        <p>Og for &aring; slette nyhetsartikler m&aring; brukeren tilh&oslash;re en gruppe men &#039;Delete News Articles&#039; tillatelse.</p>
<p>For &aring; endre layout malene, m&aring; brukeren tilh&oslash;re en gruppe med &#039;Modify Templates&#039; tillatelse.</p>
<p>For &aring; redigere globale nyhets preferanser, m&aring; brukeren tilh&oslash;re en gruppe med &#039;Modify Site Preferences&#039; tillatelse.</p>
<p>Og for &aring; godkjenne nyheter for forsidevisning m&aring; brukeren i tillegg tilh&oslash;re en gruppe med &#039;Approve News&#039; tillatelse.</p>

<h3>Hvordan bruker jeg modulen?</h3>
<p>Den enkleste m&aring;ten &aring; bruke den er med en {news} omslagstagg (lukker inn modulen i en tagg, for &aring; forenkle syntaksen).  
Dette vil sette inn modulen i din mal eller side hvor du m&aring;tte &oslash;nske, og vise nyhetsartikler.  Koden vil se ut noe slikt som: <code>{news number=&#039;5&#039;}</code></p>

<h3>Maler</h3>
<p>Fra og med versjon 2.3 st&oslash;tter News flere database maler, og st&oslash;tter ikke lenger filmaler. Brukere som brukte det gamle filmal systemet kan f&oslash;lge disse trinnene (for hver filmal):
<ul>
<li>Kopier filmalen til utklippstavla</li>
<li>Opprett en ny databasemal <em>(enten sammendrag eller detalj som trengs)</em>.  Gi den nye malen samme navn (inkludert .tpl endelse) som den gamle filmalen, og lim inn innholdet.</li>
<li>Trykk Oppdater</li>
</ul>

<p>Dersom du f&oslash;lger disse trinnene skulle det l&oslash;se problemet med at dine nyhetsamaler ikke blir funnet og lignende smarty feil, n&aring;r du oppgraderer til en versjon av CMS som har News 2.3 eller h&oslash;yere.</p>';
$lang['utmz'] = '156861353.1243118268.1334.33.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
$lang['utma'] = '156861353.179052623084110100.1210423577.1244280118.1244298455.1393';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353.2.10.1244298455';
?>